
From: Gerd Knorr <kraxel@bytesex.org>

This patch has some minor cleanups for the v4l i2c modules: Don't ignore
the i2c_add_driver return value and mark the init+exit functions with
__init + __exit.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/media/video/msp3400.c |    7 +++----
 25-akpm/drivers/media/video/tda7432.c |    8 ++++----
 25-akpm/drivers/media/video/tda9875.c |    7 +++----
 25-akpm/drivers/media/video/tvaudio.c |    8 ++++----
 25-akpm/drivers/media/video/tvmixer.c |    8 ++++----
 25-akpm/include/media/id.h            |    1 -
 6 files changed, 18 insertions(+), 21 deletions(-)

diff -puN drivers/media/video/msp3400.c~v4l-i2c-cleanups drivers/media/video/msp3400.c
--- 25/drivers/media/video/msp3400.c~v4l-i2c-cleanups	Tue Aug 31 14:40:50 2004
+++ 25-akpm/drivers/media/video/msp3400.c	Tue Aug 31 14:40:50 2004
@@ -1552,13 +1552,12 @@ static int msp_command(struct i2c_client
 
 /* ----------------------------------------------------------------------- */
 
-static int msp3400_init_module(void)
+static int __init msp3400_init_module(void)
 {
-	i2c_add_driver(&driver);
-	return 0;
+	return i2c_add_driver(&driver);
 }
 
-static void msp3400_cleanup_module(void)
+static void __exit msp3400_cleanup_module(void)
 {
 	i2c_del_driver(&driver);
 }
diff -puN drivers/media/video/tda7432.c~v4l-i2c-cleanups drivers/media/video/tda7432.c
--- 25/drivers/media/video/tda7432.c~v4l-i2c-cleanups	Tue Aug 31 14:40:50 2004
+++ 25-akpm/drivers/media/video/tda7432.c	Tue Aug 31 14:40:50 2004
@@ -532,17 +532,17 @@ static struct i2c_client client_template
 	.driver     = &driver, 
 };
 
-static int tda7432_init(void)
+static int __init tda7432_init(void)
 {
 	if ( (loudness < 0) || (loudness > 15) ) {
 		printk(KERN_ERR "tda7432: loudness parameter must be between 0 and 15\n");
 		return -EINVAL;
 	}
-	i2c_add_driver(&driver);
-	return 0;
+
+	return i2c_add_driver(&driver);
 }
 
-static void tda7432_fini(void)
+static void __exit tda7432_fini(void)
 {
 	i2c_del_driver(&driver);
 }
diff -puN drivers/media/video/tda9875.c~v4l-i2c-cleanups drivers/media/video/tda9875.c
--- 25/drivers/media/video/tda9875.c~v4l-i2c-cleanups	Tue Aug 31 14:40:50 2004
+++ 25-akpm/drivers/media/video/tda9875.c	Tue Aug 31 14:40:50 2004
@@ -403,13 +403,12 @@ static struct i2c_client client_template
         .driver    = &driver,
 };
 
-static int tda9875_init(void)
+static int __init tda9875_init(void)
 {
-	i2c_add_driver(&driver);
-	return 0;
+	return i2c_add_driver(&driver);
 }
 
-static void tda9875_fini(void)
+static void __exit tda9875_fini(void)
 {
 	i2c_del_driver(&driver);
 }
diff -puN drivers/media/video/tvaudio.c~v4l-i2c-cleanups drivers/media/video/tvaudio.c
--- 25/drivers/media/video/tvaudio.c~v4l-i2c-cleanups	Tue Aug 31 14:40:50 2004
+++ 25-akpm/drivers/media/video/tvaudio.c	Tue Aug 31 14:40:50 2004
@@ -1651,7 +1651,7 @@ static struct i2c_client client_template
         .driver     = &driver,
 };
 
-static int audiochip_init_module(void)
+static int __init audiochip_init_module(void)
 {
 	struct CHIPDESC  *desc;
 	printk(KERN_INFO "tvaudio: TV audio decoder + audio/video mux driver\n");
@@ -1659,11 +1659,11 @@ static int audiochip_init_module(void)
 	for (desc = chiplist; desc->name != NULL; desc++)
 		printk("%s%s", (desc == chiplist) ? "" : ",",desc->name);
 	printk("\n");
-	i2c_add_driver(&driver);
-	return 0;
+
+	return i2c_add_driver(&driver);
 }
 
-static void audiochip_cleanup_module(void)
+static void __exit audiochip_cleanup_module(void)
 {
 	i2c_del_driver(&driver);
 }
diff -puN drivers/media/video/tvmixer.c~v4l-i2c-cleanups drivers/media/video/tvmixer.c
--- 25/drivers/media/video/tvmixer.c~v4l-i2c-cleanups	Tue Aug 31 14:40:50 2004
+++ 25-akpm/drivers/media/video/tvmixer.c	Tue Aug 31 14:40:50 2004
@@ -330,17 +330,17 @@ static int tvmixer_clients(struct i2c_cl
 
 /* ----------------------------------------------------------------------- */
 
-static int tvmixer_init_module(void)
+static int __init tvmixer_init_module(void)
 {
 	int i;
 	
 	for (i = 0; i < DEV_MAX; i++)
 		devices[i].minor = -1;
-	i2c_add_driver(&driver);
-	return 0;
+
+	return i2c_add_driver(&driver);
 }
 
-static void tvmixer_cleanup_module(void)
+static void __exit tvmixer_cleanup_module(void)
 {
 	int i;
 	
diff -puN include/media/id.h~v4l-i2c-cleanups include/media/id.h
--- 25/include/media/id.h~v4l-i2c-cleanups	Tue Aug 31 14:40:50 2004
+++ 25-akpm/include/media/id.h	Tue Aug 31 14:40:50 2004
@@ -35,4 +35,3 @@
 #ifndef I2C_ALGO_SAA7134
 # define I2C_ALGO_SAA7134 0x090000
 #endif
-
_
